@@ -9,7 +9,7 @@ mod string;
 use itertools::Itertools;
 use tombi_ast::AstNode;
 use tombi_comment_directive::value::{
-    ArrayCommonLintRules, ArrayFormatRules, TombiValueDirectiveContent,
+    ArrayCommonFormatRules, ArrayCommonLintRules, TombiValueDirectiveContent,
 };
 use tombi_document_tree::TryIntoDocumentTree;
 use tombi_schema_store::{
@@ -35,7 +35,9 @@ pub async fn array_values_order<'a>(
     values_with_comma: Vec<(tombi_ast::Value, Option<tombi_ast::Comma>)>,
     current_schema: Option<&'a CurrentSchema<'a>>,
     schema_context: &'a SchemaContext<'a>,
-    comment_directive: Option<TombiValueDirectiveContent<ArrayFormatRules, ArrayCommonLintRules>>,
+    comment_directive: Option<
+        TombiValueDirectiveContent<ArrayCommonFormatRules, ArrayCommonLintRules>,
+    >,
 ) -> Vec<crate::Change> {
     if values_with_comma.is_empty() {
         return Vec::with_capacity(0);
@@ -83,7 +85,7 @@ pub async fn array_values_order<'a>(
 
     let sorted_values_with_comma = match values_order {
         XTombiArrayValuesOrder::All(values_order) => {
-            sort_array_values_order_all(
+            get_sorted_values_order_all(
                 values_with_comma,
                 current_schema,
                 schema_context,
@@ -92,7 +94,7 @@ pub async fn array_values_order<'a>(
             .await
         }
         XTombiArrayValuesOrder::Groups(values_order_group) => {
-            sort_array_values_order_groups(
+            get_sorted_values_order_groups(
                 values_with_comma,
                 current_schema,
                 schema_context,
@@ -148,7 +150,7 @@ pub async fn array_values_order<'a>(
     changes
 }
 
-async fn sort_array_values_order_all<'a>(
+async fn get_sorted_values_order_all<'a>(
     values_with_comma: Vec<(tombi_ast::Value, Option<tombi_ast::Comma>)>,
     current_schema: Option<&'a CurrentSchema<'a>>,
     schema_context: &'a SchemaContext<'a>,
@@ -169,7 +171,7 @@ async fn sort_array_values_order_all<'a>(
     Some(sort_array_values(sortable_values, order))
 }
 
-async fn sort_array_values_order_groups<'a>(
+async fn get_sorted_values_order_groups<'a>(
     mut values_with_comma: Vec<(tombi_ast::Value, Option<tombi_ast::Comma>)>,
     current_schema: Option<&'a CurrentSchema<'a>>,
     schema_context: &'a SchemaContext<'a>,
