@@ -1,20 +1,59 @@
-use indexmap::{map::Entry, IndexMap};
+use indexmap::{
+    map::{Entry, MutableKeys},
+    IndexMap,
+};
 use itertools::Itertools;
-use tombi_ast::{AstChildren, AstNode};
+use tombi_ast::{AstChildren, AstNode, TombiValueCommentDirective};
 use tombi_toml_version::TomlVersion;
 
 use crate::{
-    support::comment::try_new_comment, Array, DocumentTreeAndErrors, IntoDocumentTreeAndErrors,
-    Key, Value, ValueImpl, ValueType,
+    Array, DocumentTreeAndErrors, IntoDocumentTreeAndErrors, Key, Value, ValueImpl, ValueType,
 };
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum TableKind {
+    /// A root table.
     Root,
+
+    /// A table.
+    ///
+    /// ```toml
+    /// [key1.key2.key3]
+    ///            ^^^^
+    /// ```
     Table,
+
+    /// A table of parent keys.
+    ///
+    /// ```toml
+    /// [key1.key2.key3]
+    ///  ^^^^^^^^^
+    /// ```
     ParentTable,
-    InlineTable,
+
+    /// An inline table.
+    ///
+    /// ```toml
+    /// key1 = { key2 = "value" }
+    ///        ^^^^^^^^^^^^^^^^^^
+    ///
+    /// ```
+    InlineTable { has_comment: bool },
+
+    /// A table of parent keys.
+    ///
+    /// ```toml
+    /// key1.key2.key3 = "value"
+    /// ^^^^^^^^^
+    /// ```
     ParentKey,
+
+    /// A key-value.
+    ///
+    /// ```toml
+    /// key1.key2.key3 = "value"
+    ///           ^^^^^^^^^^^^^^
+    /// ```
     KeyValue,
 }
 
@@ -24,6 +63,8 @@ pub struct Table {
     range: tombi_text::Range,
     symbol_range: tombi_text::Range,
     key_values: IndexMap<Key, Value>,
+    pub(crate) comment_directives: Option<Box<Vec<TombiValueCommentDirective>>>,
+    pub(crate) inner_comment_directives: Option<Box<Vec<TombiValueCommentDirective>>>,
 }
 
 impl Table {
@@ -33,6 +74,8 @@ impl Table {
             key_values: Default::default(),
             range: tombi_text::Range::default(),
             symbol_range: tombi_text::Range::default(),
+            comment_directives: None,
+            inner_comment_directives: None,
         }
     }
 
@@ -42,6 +85,8 @@ impl Table {
             key_values: Default::default(),
             range: node.syntax().range(),
             symbol_range: node.syntax().range(),
+            comment_directives: None,
+            inner_comment_directives: None,
         }
     }
 
@@ -56,6 +101,8 @@ impl Table {
                     .unwrap_or_else(|| node.range().start),
                 node.range().end,
             ),
+            comment_directives: None,
+            inner_comment_directives: None,
         }
     }
 
@@ -70,20 +117,35 @@ impl Table {
                     .unwrap_or_else(|| node.range().start),
                 node.range().end,
             ),
+            comment_directives: None,
+            inner_comment_directives: None,
         }
     }
 
     pub(crate) fn new_inline_table(node: &tombi_ast::InlineTable) -> Self {
+        let has_comment = !node.inner_begin_dangling_comments().is_empty()
+            || !node
+                .inner_end_dangling_comments()
+                .into_iter()
+                .flatten()
+                .collect_vec()
+                .is_empty()
+            || node.has_inner_comments();
+
+        let symbol_range = tombi_text::Range::new(
+            node.brace_start()
+                .map_or_else(|| node.range().start, |brace| brace.range().start),
+            node.brace_end()
+                .map_or_else(|| node.range().end, |brace| brace.range().end),
+        );
+
         Self {
-            kind: TableKind::InlineTable,
+            kind: TableKind::InlineTable { has_comment },
             key_values: Default::default(),
             range: node.syntax().range(),
-            symbol_range: tombi_text::Range::new(
-                node.brace_start()
-                    .map_or_else(|| node.range().start, |brace| brace.range().start),
-                node.brace_end()
-                    .map_or_else(|| node.range().end, |brace| brace.range().end),
-            ),
+            symbol_range,
+            comment_directives: None,
+            inner_comment_directives: None,
         }
     }
 
@@ -93,6 +155,8 @@ impl Table {
             key_values: Default::default(),
             range: node.syntax().range(),
             symbol_range: node.syntax().range(),
+            comment_directives: None,
+            inner_comment_directives: None,
         }
     }
 
@@ -102,6 +166,8 @@ impl Table {
             key_values: Default::default(),
             range: self.range,
             symbol_range: self.symbol_range,
+            comment_directives: self.comment_directives.clone(),
+            inner_comment_directives: None,
         }
     }
 
@@ -111,9 +177,21 @@ impl Table {
             key_values: Default::default(),
             range: tombi_text::Range::new(parent_key.range().start, self.range.end),
             symbol_range: tombi_text::Range::new(parent_key.range().start, self.symbol_range.end),
+            comment_directives: parent_key.comment_directives.clone(),
+            inner_comment_directives: None,
         }
     }
 
+    #[inline]
+    pub fn comment_directives(&self) -> Option<&[TombiValueCommentDirective]> {
+        self.comment_directives.as_deref().map(|v| &**v)
+    }
+
+    #[inline]
+    pub fn inner_comment_directives(&self) -> Option<&[TombiValueCommentDirective]> {
+        self.inner_comment_directives.as_deref().map(|v| &**v)
+    }
+
     #[inline]
     pub fn contains_key(&self, key: &str) -> bool {
         self.key_values.contains_key(key)
@@ -146,20 +224,24 @@ impl Table {
                     .zip(other.key_values.values())
                     .next()
                 {
-                    Some((Value::Table(table1), _)) => table1.kind() == InlineTable,
-                    Some((_, Value::Table(table2))) => table2.kind() == InlineTable,
+                    Some((Value::Table(table1), _)) => {
+                        matches!(table1.kind(), TableKind::InlineTable { .. })
+                    }
+                    Some((_, Value::Table(table2))) => {
+                        matches!(table2.kind(), TableKind::InlineTable { .. })
+                    }
                     Some(_) => false,
                     None => unreachable!("KeyValue must have one value."),
                 }
             }
-            (Table | InlineTable | KeyValue, Table | InlineTable)
-            | (InlineTable, ParentTable | ParentKey | KeyValue)
+            (Table | InlineTable { .. } | KeyValue, Table | InlineTable { .. })
+            | (InlineTable { .. }, ParentTable | ParentKey | KeyValue)
             | (ParentTable, ParentKey) => true,
-            (ParentTable, Table | InlineTable) => {
+            (ParentTable, Table | InlineTable { .. }) => {
                 self.kind = other.kind;
                 false
             }
-            (ParentKey, Table | InlineTable) => {
+            (ParentKey, Table | InlineTable { .. }) => {
                 self.kind = other.kind;
                 true
             }
@@ -194,9 +276,10 @@ impl Table {
                             }
                         }
                         _ => {
+                            let range = key.range();
                             errors.push(crate::Error::DuplicateKey {
-                                key: key.value().to_string(),
-                                range: key.range(),
+                                key: key.value,
+                                range,
                             });
                         }
                     }
@@ -233,7 +316,7 @@ impl Table {
                     }
                     _ => {
                         errors.push(crate::Error::DuplicateKey {
-                            key: entry.key().value().to_string(),
+                            key: entry.key().value.to_string(),
                             range: entry.key().range(),
                         });
                     }
@@ -262,6 +345,13 @@ impl Table {
         self.key_values.get(key)
     }
 
+    pub fn get_mut<K>(&mut self, key: &K) -> Option<&mut Value>
+    where
+        K: ?Sized + std::hash::Hash + indexmap::Equivalent<Key>,
+    {
+        self.key_values.get_mut(key)
+    }
+
     pub fn get_key_value<K>(&self, key: &K) -> Option<(&Key, &Value)>
     where
         K: ?Sized + std::hash::Hash + indexmap::Equivalent<Key>,
@@ -269,11 +359,42 @@ impl Table {
         self.key_values.get_key_value(key)
     }
 
-    pub fn get_mut<K>(&mut self, key: &K) -> Option<&mut Value>
+    pub fn get_key_value_mut<K>(&mut self, key: &K) -> Option<(&Key, &mut Value)>
     where
         K: ?Sized + std::hash::Hash + indexmap::Equivalent<Key>,
     {
-        self.key_values.get_mut(key)
+        self.key_values
+            .get_full_mut(key)
+            .map(|(_, key, value)| (key, value))
+    }
+
+    pub fn get_full<K>(&self, key: &K) -> Option<(usize, &Key, &Value)>
+    where
+        K: ?Sized + std::hash::Hash + indexmap::Equivalent<Key>,
+    {
+        self.key_values.get_full(key)
+    }
+
+    pub fn get_full_mut<K>(&mut self, key: &K) -> Option<(usize, &Key, &mut Value)>
+    where
+        K: ?Sized + std::hash::Hash + indexmap::Equivalent<Key>,
+    {
+        self.key_values.get_full_mut(key)
+    }
+
+    pub fn get_index_of<K>(&self, key: &K) -> Option<usize>
+    where
+        K: ?Sized + std::hash::Hash + indexmap::Equivalent<Key>,
+    {
+        self.key_values.get_index_of(key)
+    }
+
+    pub fn iter_mut(&mut self) -> impl Iterator<Item = (&Key, &mut Value)> {
+        self.key_values.iter_mut()
+    }
+
+    pub fn iter_mut2(&mut self) -> impl Iterator<Item = (&mut Key, &mut Value)> {
+        self.key_values.iter_mut2()
     }
 
     #[inline]
@@ -302,6 +423,23 @@ impl Table {
     }
 }
 
+impl std::fmt::Display for Table {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(
+            f,
+            "{{ {} }}",
+            self.key_values
+                .iter()
+                .filter_map(|(k, v)| if let crate::Value::Incomplete { .. } = &v {
+                    None
+                } else {
+                    Some(format!("{} = {}", k, v))
+                })
+                .join(", ")
+        )
+    }
+}
+
 impl From<Table> for IndexMap<Key, Value> {
     fn from(table: Table) -> IndexMap<Key, Value> {
         table.key_values
@@ -324,26 +462,83 @@ impl IntoDocumentTreeAndErrors<crate::Table> for tombi_ast::Table {
         toml_version: TomlVersion,
     ) -> DocumentTreeAndErrors<crate::Table> {
         let mut table = Table::new_table(&self);
-        let mut errors = Vec::new();
+        let mut errors = vec![];
+        let key_values = self.key_values().collect_vec();
 
-        for comment in self.header_leading_comments() {
-            if let Err(error) = try_new_comment(comment.as_ref()) {
-                errors.push(error);
+        {
+            let mut comment_directives = vec![];
+            let mut inner_comment_directives = vec![];
+
+            for comment in self.header_leading_comments() {
+                if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                    errors.push(error);
+                }
+
+                if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                    comment_directives.push(comment_directive);
+                }
+            }
+
+            if let Some(comment) = self.header_trailing_comment() {
+                if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                    errors.push(error);
+                }
+                if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                    comment_directives.push(comment_directive);
+                }
+            }
+
+            if key_values.is_empty() {
+                for comments in self.key_values_dangling_comments() {
+                    for comment in comments {
+                        if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                            errors.push(error);
+                        }
+                        if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                            inner_comment_directives.push(comment_directive);
+                        }
+                    }
+                }
+            } else {
+                for comments in self.key_values_begin_dangling_comments() {
+                    for comment in comments {
+                        if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                            errors.push(error);
+                        }
+                        if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                            inner_comment_directives.push(comment_directive);
+                        }
+                    }
+                }
+
+                for comments in self.key_values_end_dangling_comments() {
+                    for comment in comments {
+                        if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                            errors.push(error);
+                        }
+                        if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                            inner_comment_directives.push(comment_directive);
+                        }
+                    }
+                }
+            }
+
+            if !comment_directives.is_empty() {
+                table.comment_directives = Some(Box::new(comment_directives));
+            }
+            if !inner_comment_directives.is_empty() {
+                table.inner_comment_directives = Some(Box::new(inner_comment_directives));
             }
         }
 
-        if let Some(comment) = self.header_tailing_comment() {
-            if let Err(error) = try_new_comment(comment.as_ref()) {
-                errors.push(error);
-            }
-        }
+        let empty_table = table.clone();
 
         let Some(header_keys) = self.header() else {
             errors.push(crate::Error::IncompleteNode {
                 range: self.range(),
             });
             return DocumentTreeAndErrors {
-                tree: table,
+                tree: empty_table,
                 errors,
             };
         };
@@ -353,10 +548,9 @@ impl IntoDocumentTreeAndErrors<crate::Table> for tombi_ast::Table {
             .into();
         if !errs.is_empty() {
             errors.extend(errs);
-            return make_keys_table(header_keys, table, errors);
         }
 
-        for key_value in self.key_values() {
+        for key_value in key_values {
             let (other, errs) = key_value.into_document_tree_and_errors(toml_version).into();
             if !errs.is_empty() {
                 errors.extend(errs);
@@ -366,23 +560,23 @@ impl IntoDocumentTreeAndErrors<crate::Table> for tombi_ast::Table {
             }
         }
 
-        let array_of_table_keys =
-            get_array_of_tables_keys(self.array_of_tables_keys(), toml_version, &mut errors);
+        let array_of_table_keys = get_array_of_tables_keys(
+            self.array_of_tables_keys(toml_version),
+            toml_version,
+            &mut errors,
+        );
 
         let mut is_array_of_table = false;
-        while let Some(key) = header_keys.pop() {
+        while let Some(mut key) = header_keys.pop() {
+            key.comment_directives = table.comment_directives.clone();
             if is_array_of_table {
                 if let Err(errs) =
                     insert_array_of_tables(&mut table, key, Array::new_parent_array_of_tables)
                 {
                     errors.extend(errs);
-                    return make_keys_table(header_keys, table, errors);
                 };
-            } else if let Err(errs) =
-                insert_table(&mut table, key, |table| table.new_parent_table())
-            {
+            } else if let Err(errs) = insert_table(&mut table, key) {
                 errors.extend(errs);
-                return make_keys_table(header_keys, table, errors);
             };
 
             is_array_of_table = array_of_table_keys.contains(&header_keys);
@@ -401,26 +595,83 @@ impl IntoDocumentTreeAndErrors<Table> for tombi_ast::ArrayOfTable {
         toml_version: TomlVersion,
     ) -> DocumentTreeAndErrors<Table> {
         let mut table = Table::new_array_of_table(&self);
-        let mut errors = Vec::new();
+        let mut errors = vec![];
+        let key_values = self.key_values().collect_vec();
 
-        for comment in self.header_leading_comments() {
-            if let Err(error) = try_new_comment(comment.as_ref()) {
-                errors.push(error);
+        {
+            let mut comment_directives = vec![];
+            let mut inner_comment_directives = vec![];
+
+            for comment in self.header_leading_comments() {
+                if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                    errors.push(error);
+                }
+                if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                    comment_directives.push(comment_directive);
+                }
+            }
+
+            if let Some(comment) = self.header_trailing_comment() {
+                if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                    errors.push(error);
+                }
+                if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                    comment_directives.push(comment_directive);
+                }
+            }
+
+            if key_values.is_empty() {
+                for comments in self.key_values_dangling_comments() {
+                    for comment in comments {
+                        if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                            errors.push(error);
+                        }
+                        if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                            inner_comment_directives.push(comment_directive);
+                        }
+                    }
+                }
+            } else {
+                for comments in self.key_values_begin_dangling_comments() {
+                    for comment in comments {
+                        if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                            errors.push(error);
+                        }
+                        if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                            inner_comment_directives.push(comment_directive);
+                        }
+                    }
+                }
+
+                for comments in self.key_values_end_dangling_comments() {
+                    for comment in comments {
+                        if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                            errors.push(error);
+                        }
+                        if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                            inner_comment_directives.push(comment_directive);
+                        }
+                    }
+                }
+            }
+
+            if !comment_directives.is_empty() {
+                table.comment_directives = Some(Box::new(comment_directives));
+            }
+            if !inner_comment_directives.is_empty() {
+                table.inner_comment_directives = Some(Box::new(inner_comment_directives));
             }
         }
 
-        if let Some(comment) = self.header_tailing_comment() {
-            if let Err(error) = try_new_comment(comment.as_ref()) {
-                errors.push(error);
-            }
-        }
+        let empty_table = table.clone();
 
         let Some(header_keys) = self.header() else {
             errors.push(crate::Error::IncompleteNode {
                 range: self.range(),
             });
+
             return DocumentTreeAndErrors {
-                tree: table,
+                tree: empty_table,
                 errors,
             };
         };
@@ -428,12 +679,12 @@ impl IntoDocumentTreeAndErrors<Table> for tombi_ast::ArrayOfTable {
         let (mut header_keys, errs) = header_keys
             .into_document_tree_and_errors(toml_version)
             .into();
+
         if !errs.is_empty() {
             errors.extend(errs);
-            return make_keys_table(header_keys, table, errors);
         }
 
-        for key_value in self.key_values() {
+        for key_value in key_values {
             let (other, errs) = key_value.into_document_tree_and_errors(toml_version).into();
             if !errs.is_empty() {
                 errors.extend(errs);
@@ -446,10 +697,10 @@ impl IntoDocumentTreeAndErrors<Table> for tombi_ast::ArrayOfTable {
         let array_of_table_keys =
             get_array_of_tables_keys(self.array_of_tables_keys(), toml_version, &mut errors);
 
-        if let Some(key) = header_keys.pop() {
+        if let Some(mut key) = header_keys.pop() {
+            key.comment_directives = table.comment_directives.clone();
             if let Err(errs) = insert_array_of_tables(&mut table, key, Array::new_array_of_tables) {
                 errors.extend(errs);
-                return make_keys_table(header_keys, table, errors);
             }
         }
 
@@ -460,13 +711,9 @@ impl IntoDocumentTreeAndErrors<Table> for tombi_ast::ArrayOfTable {
                     insert_array_of_tables(&mut table, key, Array::new_parent_array_of_tables)
                 {
                     errors.extend(errs);
-                    return make_keys_table(header_keys, table, errors);
                 };
-            } else if let Err(errs) =
-                insert_table(&mut table, key, |table| table.new_parent_table())
-            {
+            } else if let Err(errs) = insert_table(&mut table, key) {
                 errors.extend(errs);
-                return make_keys_table(header_keys, table, errors);
             };
 
             is_array_of_table = array_of_table_keys.contains(&header_keys);
@@ -500,21 +747,28 @@ impl IntoDocumentTreeAndErrors<Table> for tombi_ast::KeyValue {
         self,
         toml_version: tombi_toml_version::TomlVersion,
     ) -> DocumentTreeAndErrors<Table> {
-        let table = Table::new_key_value(&self);
+        let mut table = Table::new_key_value(&self);
         let mut errors = Vec::new();
 
+        let mut comment_directives = vec![];
+
         for comment in self.leading_comments() {
-            if let Err(error) = try_new_comment(comment.as_ref()) {
+            if let Err(error) = crate::support::comment::try_new_comment(&comment) {
                 errors.push(error);
             }
+            if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                comment_directives.push(comment_directive);
+            }
         }
 
+        let empty_table = table.clone();
+
         let Some(keys) = self.keys() else {
             errors.push(crate::Error::IncompleteNode {
                 range: self.range(),
             });
             return DocumentTreeAndErrors {
-                tree: table,
+                tree: empty_table,
                 errors,
             };
         };
@@ -522,15 +776,24 @@ impl IntoDocumentTreeAndErrors<Table> for tombi_ast::KeyValue {
         let (mut keys, errs) = keys.into_document_tree_and_errors(toml_version).into();
         if !errs.is_empty() {
             errors.extend(errs);
-            return make_keys_table(keys, table, errors);
         }
 
         let value = match self.value() {
             Some(value) => {
-                let (value, errs) = value.into_document_tree_and_errors(toml_version).into();
+                let (mut value, errs) = value.into_document_tree_and_errors(toml_version).into();
                 if !errs.is_empty() {
                     errors.extend(errs);
                 }
+
+                if let Some(value_comment_directives) = value.comment_directives() {
+                    comment_directives.extend(value_comment_directives.iter().cloned());
+                }
+
+                if !comment_directives.is_empty() {
+                    table.comment_directives = Some(Box::new(comment_directives.clone()));
+                    value.set_comment_directives(comment_directives.clone());
+                }
+
                 value
             }
             None => {
@@ -543,25 +806,52 @@ impl IntoDocumentTreeAndErrors<Table> for tombi_ast::KeyValue {
             }
         };
 
-        let table = if let Some(key) = keys.pop() {
-            let mut seed_key_value = Table::new_key_value(&self);
-            seed_key_value.range = key.range() + value.range();
-            seed_key_value.symbol_range = key.range() + value.symbol_range();
-            match seed_key_value.insert(key, value) {
-                Ok(table) => table,
+        let mut table = if let Some(mut key) = keys.pop() {
+            table.range = key.range() + value.range();
+            table.symbol_range = key.range() + value.symbol_range();
+            if !comment_directives.is_empty() {
+                key.comment_directives = Some(Box::new(comment_directives.clone()));
+            }
+
+            match table.insert(key, value) {
+                Ok(t) => t,
                 Err(errs) => {
                     errors.extend(errs);
-                    return make_keys_table(keys, table, errors);
+
+                    return DocumentTreeAndErrors {
+                        tree: empty_table,
+                        errors,
+                    };
                 }
             }
         } else {
             return DocumentTreeAndErrors {
-                tree: table,
+                tree: empty_table,
                 errors,
             };
         };
 
-        make_keys_table(keys, table, errors)
+        for mut key in keys.into_iter().rev() {
+            let dummy_table = table.clone();
+            if !comment_directives.is_empty() {
+                key.comment_directives = Some(Box::new(comment_directives.clone()));
+            }
+
+            match table.new_parent_key(&key).insert(
+                key,
+                crate::Value::Table(std::mem::replace(&mut table, dummy_table)),
+            ) {
+                Ok(t) => table = t,
+                Err(errs) => {
+                    errors.extend(errs);
+                }
+            }
+        }
+
+        DocumentTreeAndErrors {
+            tree: table,
+            errors,
+        }
     }
 }
 
@@ -571,20 +861,109 @@ impl IntoDocumentTreeAndErrors<crate::Value> for tombi_ast::InlineTable {
         toml_version: TomlVersion,
     ) -> DocumentTreeAndErrors<crate::Value> {
         let mut table = Table::new_inline_table(&self);
-        let mut errors = Vec::new();
+        let table_kind = table.kind;
+        let mut errors = vec![];
+        let key_values = self.key_values().collect_vec();
+        {
+            let mut comment_directives = vec![];
+            let mut inner_comment_directives = vec![];
 
-        for comments in self.inner_begin_dangling_comments() {
-            for comment in comments {
-                if let Err(error) = try_new_comment(comment.as_ref()) {
+            for comment in self.leading_comments() {
+                if let Err(error) = crate::support::comment::try_new_comment(&comment) {
                     errors.push(error);
                 }
+                if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                    comment_directives.push(comment_directive);
+                }
+            }
+
+            if key_values.is_empty() {
+                for comments in self.inner_dangling_comments() {
+                    for comment in comments {
+                        if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                            errors.push(error);
+                        }
+                        if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                            inner_comment_directives.push(comment_directive);
+                        }
+                    }
+                }
+            } else {
+                for comments in self.inner_begin_dangling_comments() {
+                    for comment in comments {
+                        if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                            errors.push(error);
+                        }
+                        if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                            inner_comment_directives.push(comment_directive);
+                        }
+                    }
+                }
+
+                for comments in self.inner_end_dangling_comments() {
+                    for comment in comments {
+                        if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                            errors.push(error);
+                        }
+                        if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                            inner_comment_directives.push(comment_directive);
+                        }
+                    }
+                }
+            }
+
+            if let Some(comment) = self.trailing_comment() {
+                if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                    errors.push(error);
+                }
+                if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                    comment_directives.push(comment_directive);
+                }
+            }
+
+            if !comment_directives.is_empty() {
+                table.comment_directives = Some(Box::new(comment_directives));
+            }
+            if !inner_comment_directives.is_empty() {
+                table.inner_comment_directives = Some(Box::new(inner_comment_directives));
             }
         }
-
         table.kind = TableKind::Table;
 
         for (key_value, comma) in self.key_values_with_comma() {
-            let (other, errs) = key_value.into_document_tree_and_errors(toml_version).into();
+            let keys = key_value.keys().map(|k| k.keys());
+            let (mut other, errs) = key_value.into_document_tree_and_errors(toml_version).into();
+
+            if let Some(comma) = comma {
+                let mut comment_directives = vec![];
+                for comment in comma.leading_comments() {
+                    if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                        errors.push(error);
+                    }
+                    if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                        comment_directives.push(comment_directive);
+                    }
+                }
+                if let Some(comment) = comma.trailing_comment() {
+                    if let Err(error) = crate::support::comment::try_new_comment(&comment) {
+                        errors.push(error);
+                    }
+                    if let Some(comment_directive) = comment.get_tombi_value_directive() {
+                        comment_directives.push(comment_directive);
+                    }
+                }
+
+                if !comment_directives.is_empty() {
+                    if let Some(keys) = keys {
+                        append_comment_directives(
+                            &mut other,
+                            keys.into_iter(),
+                            &comment_directives,
+                        );
+                    }
+                    other.comment_directives = Some(Box::new(comment_directives));
+                }
+            }
 
             if !errs.is_empty() {
                 errors.extend(errs)
@@ -592,30 +971,9 @@ impl IntoDocumentTreeAndErrors<crate::Value> for tombi_ast::InlineTable {
             if let Err(errs) = table.merge(other) {
                 errors.extend(errs)
             }
-
-            if let Some(comma) = comma {
-                for comment in comma.leading_comments() {
-                    if let Err(error) = try_new_comment(comment.as_ref()) {
-                        errors.push(error);
-                    }
-                }
-                if let Some(comment) = comma.tailing_comment() {
-                    if let Err(error) = try_new_comment(comment.as_ref()) {
-                        errors.push(error);
-                    }
-                }
-            }
         }
 
-        table.kind = TableKind::InlineTable;
-
-        for comments in self.inner_end_dangling_comments() {
-            for comment in comments {
-                if let Err(error) = try_new_comment(comment.as_ref()) {
-                    errors.push(error);
-                }
-            }
-        }
+        table.kind = table_kind;
 
         DocumentTreeAndErrors {
             tree: crate::Value::Table(table),
@@ -624,6 +982,40 @@ impl IntoDocumentTreeAndErrors<crate::Value> for tombi_ast::InlineTable {
     }
 }
 
+impl<T> IntoDocumentTreeAndErrors<crate::Table> for Vec<T>
+where
+    T: IntoDocumentTreeAndErrors<crate::Table>,
+{
+    fn into_document_tree_and_errors(
+        self,
+        toml_version: TomlVersion,
+    ) -> DocumentTreeAndErrors<crate::Table> {
+        let mut errors = Vec::new();
+        let tables = self
+            .into_iter()
+            .map(|value| {
+                let (table, errs) = value.into_document_tree_and_errors(toml_version).into();
+                if !errs.is_empty() {
+                    errors.extend(errs);
+                }
+                table
+            })
+            .collect_vec();
+
+        let table = tables.into_iter().reduce(|mut acc, other| {
+            if let Err(errs) = acc.merge(other) {
+                errors.extend(errs);
+            }
+            acc
+        });
+
+        DocumentTreeAndErrors {
+            tree: table.unwrap_or_else(Table::new_empty),
+            errors,
+        }
+    }
+}
+
 impl IntoIterator for Table {
     type Item = (Key, Value);
     type IntoIter = indexmap::map::IntoIter<Key, Value>;
@@ -657,13 +1049,12 @@ fn get_array_of_tables_keys(
         .collect_vec()
 }
 
-fn insert_table(
-    table: &mut Table,
-    key: Key,
-    new_table_fn: impl Fn(&Table) -> Table,
-) -> Result<(), Vec<crate::Error>> {
-    let new_table = new_table_fn(table);
-    match new_table_fn(table).insert(key, Value::Table(std::mem::replace(table, new_table))) {
+fn insert_table(table: &mut Table, key: Key) -> Result<(), Vec<crate::Error>> {
+    let new_table = table.new_parent_table();
+    match table
+        .new_parent_table()
+        .insert(key, Value::Table(std::mem::replace(table, new_table)))
+    {
         Ok(t) => {
             *table = t;
             Ok(())
@@ -680,6 +1071,7 @@ fn insert_array_of_tables(
     let mut array = new_array_of_tables_fn(table);
     let new_table = table.new_parent_table();
     array.push(Value::Table(std::mem::replace(table, new_table)));
+    array.comment_directives = key.comment_directives.clone();
     match table.new_parent_table().insert(key, Value::Array(array)) {
         Ok(t) => {
             *table = t;
@@ -689,59 +1081,49 @@ fn insert_array_of_tables(
     }
 }
 
-fn make_keys_table(
-    keys: Vec<crate::Key>,
-    mut table: crate::Table,
-    mut errors: Vec<crate::Error>,
-) -> DocumentTreeAndErrors<crate::Table> {
-    for key in keys.into_iter().rev() {
-        let dummy_table = table.clone();
-        match table.new_parent_key(&key).insert(
-            key,
-            crate::Value::Table(std::mem::replace(&mut table, dummy_table)),
-        ) {
-            Ok(t) => table = t,
-            Err(errs) => {
-                errors.extend(errs);
-            }
-        }
-    }
-    DocumentTreeAndErrors {
-        tree: table,
-        errors,
-    }
-}
-
-impl<T> IntoDocumentTreeAndErrors<crate::Table> for Vec<T>
-where
-    T: IntoDocumentTreeAndErrors<crate::Table>,
-{
-    fn into_document_tree_and_errors(
-        self,
-        toml_version: TomlVersion,
-    ) -> DocumentTreeAndErrors<crate::Table> {
-        let mut errors = Vec::new();
-        let tables = self
-            .into_iter()
-            .map(|value| {
-                let (table, errs) = value.into_document_tree_and_errors(toml_version).into();
-                if !errs.is_empty() {
-                    errors.extend(errs);
-                }
-                table
-            })
-            .collect_vec();
-
-        let table = tables.into_iter().reduce(|mut acc, other| {
-            if let Err(errs) = acc.merge(other) {
-                errors.extend(errs);
-            }
-            acc
-        });
-
-        DocumentTreeAndErrors {
-            tree: table.unwrap_or_else(Table::new_empty),
-            errors,
+fn append_comment_directives(
+    table: &mut Table,
+    mut keys: impl Iterator<Item = tombi_ast::Key>,
+    comment_directives: &Vec<TombiValueCommentDirective>,
+) {
+    // Get the next key in the path
+    let Some(ast_key) = keys.next() else {
+        // No more keys, append comment directives to the final table
+        if let Some(table_comment_directives) = table.comment_directives.as_mut() {
+            table_comment_directives.extend(comment_directives.iter().cloned());
+        } else {
+            table.comment_directives = Some(Box::new(comment_directives.clone()));
         }
+        return;
+    };
+
+    // Since Table has only one key, we can directly access it without iteration
+    let temp_key_values = std::mem::replace(&mut table.key_values, IndexMap::new());
+
+    // Extract the single key-value pair
+    let Some((mut key, value)) = temp_key_values.into_iter().next() else {
+        return;
+    };
+
+    // Check if this is the key we're looking for
+    if key == ast_key {
+        // Update the key's comment directives
+        if let Some(key_comment_directives) = key.comment_directives.as_mut() {
+            key_comment_directives.extend(comment_directives.iter().cloned());
+        } else {
+            key.comment_directives = Some(Box::new(comment_directives.clone()));
+        }
+
+        if let Value::Table(mut nested_table) = value {
+            // Recursively process the remaining keys
+            append_comment_directives(&mut nested_table, keys, comment_directives);
+            table.key_values.insert(key, Value::Table(nested_table));
+        } else {
+            // Put the value back if it's not a table
+            table.key_values.insert(key, value);
+        }
+    } else {
+        // Key doesn't match, put it back
+        table.key_values.insert(key, value);
     }
 }
