@@ -1,5 +1,7 @@
 use tower_lsp::lsp_types::{CompletionTextEdit, InsertTextFormat, TextEdit, Url};
 
+use crate::completion::completion_hint::{AddLeadingComma, AddTrailingComma};
+
 use super::CompletionHint;
 
 #[derive(Debug, Clone, PartialEq, Eq)]
@@ -30,7 +32,27 @@ impl CompletionEdit {
                     new_text: "".to_string(),
                 }]),
             }),
-            _ => None,
+            Some(CompletionHint::InArray {
+                add_leading_comma,
+                add_trailing_comma,
+            }) => {
+                let new_text = match add_trailing_comma {
+                    Some(_) => format!("${{1:{label}}},$0"),
+                    None => format!("${{0:{label}}}"),
+                };
+                let additional_text_edits =
+                    head_comma_text_edits(add_leading_comma, add_trailing_comma, position);
+
+                Some(Self {
+                    text_edit: CompletionTextEdit::Edit(TextEdit {
+                        new_text,
+                        range: tombi_text::Range::at(position).into(),
+                    }),
+                    insert_text_format: Some(InsertTextFormat::SNIPPET),
+                    additional_text_edits,
+                })
+            }
+            Some(CompletionHint::InTableHeader | CompletionHint::Comma { .. }) | None => None,
         }
     }
 
@@ -78,14 +100,36 @@ impl CompletionEdit {
                     new_text: "".to_string(),
                 }]),
             }),
-            Some(CompletionHint::InArray | CompletionHint::InTableHeader) | None => Some(Self {
-                text_edit: CompletionTextEdit::Edit(TextEdit {
-                    new_text: format!("{quote}$1{quote}$0"),
-                    range: tombi_text::Range::at(position).into(),
-                }),
-                insert_text_format: Some(InsertTextFormat::SNIPPET),
-                additional_text_edits: None,
-            }),
+            Some(CompletionHint::InArray {
+                add_leading_comma,
+                add_trailing_comma,
+            }) => {
+                let new_text = match add_trailing_comma {
+                    Some(_) => format!("{quote}$1{quote},$0"),
+                    None => format!("{quote}$1{quote}$0"),
+                };
+                let additional_text_edits =
+                    head_comma_text_edits(add_leading_comma, add_trailing_comma, position);
+
+                Some(Self {
+                    text_edit: CompletionTextEdit::Edit(TextEdit {
+                        new_text,
+                        range: tombi_text::Range::at(position).into(),
+                    }),
+                    insert_text_format: Some(InsertTextFormat::SNIPPET),
+                    additional_text_edits,
+                })
+            }
+            Some(CompletionHint::InTableHeader | CompletionHint::Comma { .. }) | None => {
+                Some(Self {
+                    text_edit: CompletionTextEdit::Edit(TextEdit {
+                        new_text: format!("{quote}$1{quote}$0"),
+                        range: tombi_text::Range::at(position).into(),
+                    }),
+                    insert_text_format: Some(InsertTextFormat::SNIPPET),
+                    additional_text_edits: None,
+                })
+            }
         }
     }
 
@@ -122,38 +166,30 @@ impl CompletionEdit {
                     new_text: "".to_string(),
                 }]),
             }),
-            Some(CompletionHint::InArray | CompletionHint::InTableHeader) | None => Some(Self {
-                text_edit: CompletionTextEdit::Edit(TextEdit {
-                    new_text: "[$1]$0".to_string(),
-                    range: tombi_text::Range::at(position).into(),
-                }),
-                insert_text_format: Some(InsertTextFormat::SNIPPET),
-                additional_text_edits: None,
-            }),
-        }
-    }
+            Some(CompletionHint::InArray {
+                add_leading_comma,
+                add_trailing_comma,
+            }) => {
+                let new_text = match add_trailing_comma {
+                    Some(_) => format!("[$1],$0"),
+                    None => format!("[$1]$0"),
+                };
+                let additional_text_edits =
+                    head_comma_text_edits(add_leading_comma, add_trailing_comma, position);
 
-    pub fn new_inline_table(
-        position: tombi_text::Position,
-        completion_hint: Option<CompletionHint>,
-    ) -> Option<Self> {
-        match completion_hint {
-            Some(CompletionHint::DotTrigger { range, .. }) => Some(Self {
-                text_edit: CompletionTextEdit::Edit(TextEdit {
-                    new_text: " = { $1 }$0".to_string(),
-                    range: tombi_text::Range::at(position).into(),
-                }),
-                insert_text_format: Some(InsertTextFormat::SNIPPET),
-                additional_text_edits: Some(vec![TextEdit {
-                    range: range.into(),
-                    new_text: "".to_string(),
-                }]),
-            }),
-            Some(CompletionHint::InTableHeader) => None,
-            Some(CompletionHint::InArray | CompletionHint::EqualTrigger { .. }) | None => {
                 Some(Self {
                     text_edit: CompletionTextEdit::Edit(TextEdit {
-                        new_text: "{ $1 }$0".to_string(),
+                        new_text,
+                        range: tombi_text::Range::at(position).into(),
+                    }),
+                    insert_text_format: Some(InsertTextFormat::SNIPPET),
+                    additional_text_edits,
+                })
+            }
+            Some(CompletionHint::InTableHeader | CompletionHint::Comma { .. }) | None => {
+                Some(Self {
+                    text_edit: CompletionTextEdit::Edit(TextEdit {
+                        new_text: "[$1]$0".to_string(),
                         range: tombi_text::Range::at(position).into(),
                     }),
                     insert_text_format: Some(InsertTextFormat::SNIPPET),
@@ -163,20 +199,82 @@ impl CompletionEdit {
         }
     }
 
+    pub fn new_inline_table(
+        position: tombi_text::Position,
+        completion_hint: Option<CompletionHint>,
+    ) -> Option<Self> {
+        match completion_hint {
+            Some(
+                CompletionHint::DotTrigger { range, .. } | CompletionHint::EqualTrigger { range },
+            ) => Some(Self {
+                text_edit: CompletionTextEdit::Edit(TextEdit {
+                    new_text: " = {{ $1 }}$0".to_string(),
+                    range: tombi_text::Range::at(position).into(),
+                }),
+                insert_text_format: Some(InsertTextFormat::SNIPPET),
+                additional_text_edits: Some(vec![TextEdit {
+                    range: range.into(),
+                    new_text: "".to_string(),
+                }]),
+            }),
+            Some(CompletionHint::InArray {
+                add_leading_comma,
+                add_trailing_comma,
+            }) => {
+                let new_text = match add_trailing_comma {
+                    Some(_) => format!("{{ $1 }},$0"),
+                    None => format!("{{ $1 }}$0"),
+                };
+                let additional_text_edits =
+                    head_comma_text_edits(add_leading_comma, add_trailing_comma, position);
+
+                Some(Self {
+                    text_edit: CompletionTextEdit::Edit(TextEdit {
+                        new_text,
+                        range: tombi_text::Range::at(position).into(),
+                    }),
+                    insert_text_format: Some(InsertTextFormat::SNIPPET),
+                    additional_text_edits,
+                })
+            }
+            Some(CompletionHint::InTableHeader) => None,
+            Some(CompletionHint::Comma { .. }) | None => Some(Self {
+                text_edit: CompletionTextEdit::Edit(TextEdit {
+                    new_text: "{{ $1 }}$0".to_string(),
+                    range: tombi_text::Range::at(position).into(),
+                }),
+                insert_text_format: Some(InsertTextFormat::SNIPPET),
+                additional_text_edits: None,
+            }),
+        }
+    }
+
     pub fn new_key(
         key_name: &str,
         key_range: tombi_text::Range,
         completion_hint: Option<CompletionHint>,
     ) -> Option<Self> {
         match completion_hint {
-            Some(CompletionHint::InArray) => Some(Self {
-                text_edit: CompletionTextEdit::Edit(TextEdit {
-                    new_text: format!("{{ {key_name}$1 }}$0"),
-                    range: key_range.into(),
-                }),
-                insert_text_format: Some(InsertTextFormat::SNIPPET),
-                additional_text_edits: None,
-            }),
+            Some(CompletionHint::InArray {
+                add_leading_comma,
+                add_trailing_comma,
+            }) => {
+                let new_text = match add_trailing_comma {
+                    Some(_) => format!("{{ {key_name}$1 }},$0"),
+                    None => format!("{{ {key_name}$1 }}$0"),
+                };
+                let additional_text_edits =
+                    head_comma_text_edits(add_leading_comma, add_trailing_comma, key_range.start);
+
+                Some(Self {
+                    text_edit: CompletionTextEdit::Edit(TextEdit {
+                        new_text,
+                        range: key_range.into(),
+                    }),
+                    insert_text_format: Some(InsertTextFormat::SNIPPET),
+                    additional_text_edits,
+                })
+            }
             Some(CompletionHint::EqualTrigger { range, .. }) => Some(Self {
                 text_edit: CompletionTextEdit::Edit(TextEdit {
                     new_text: format!(" = {{ {key_name}$1 }}$0"),
@@ -199,7 +297,7 @@ impl CompletionEdit {
                     new_text: "".to_string(),
                 }]),
             }),
-            Some(CompletionHint::InTableHeader) | None => None,
+            Some(CompletionHint::InTableHeader | CompletionHint::Comma { .. }) | None => None,
         }
     }
 
@@ -209,17 +307,29 @@ impl CompletionEdit {
         completion_hint: Option<CompletionHint>,
     ) -> Option<Self> {
         match completion_hint {
-            Some(CompletionHint::InArray) => Some(Self {
-                text_edit: CompletionTextEdit::Edit(TextEdit {
-                    new_text: format!("{{ ${{0:{key_name}}} }}"),
-                    range: key_range.into(),
-                }),
-                insert_text_format: Some(InsertTextFormat::SNIPPET),
-                additional_text_edits: None,
-            }),
+            Some(CompletionHint::InArray {
+                add_leading_comma,
+                add_trailing_comma,
+            }) => {
+                let new_text = match add_trailing_comma {
+                    Some(_) => format!("{{ ${{1:{key_name}}} }},$0"),
+                    None => format!("{{ ${{1:{key_name}}} }}$0"),
+                };
+                let additional_text_edits =
+                    head_comma_text_edits(add_leading_comma, add_trailing_comma, key_range.start);
+
+                Some(Self {
+                    text_edit: CompletionTextEdit::Edit(TextEdit {
+                        new_text,
+                        range: key_range.into(),
+                    }),
+                    insert_text_format: Some(InsertTextFormat::SNIPPET),
+                    additional_text_edits,
+                })
+            }
             Some(CompletionHint::EqualTrigger { range, .. }) => Some(Self {
                 text_edit: CompletionTextEdit::Edit(TextEdit {
-                    new_text: format!(" = {{ ${{0:{key_name}}} }}"),
+                    new_text: format!(" = {{ ${{1:{key_name}}} }}$0"),
                     range: range.into(),
                 }),
                 insert_text_format: Some(InsertTextFormat::SNIPPET),
@@ -239,14 +349,16 @@ impl CompletionEdit {
                     new_text: "".to_string(),
                 }]),
             }),
-            Some(CompletionHint::InTableHeader) | None => Some(Self {
-                text_edit: CompletionTextEdit::Edit(TextEdit {
-                    new_text: format!("${{0:{key_name}}}"),
-                    range: key_range.into(),
-                }),
-                insert_text_format: Some(InsertTextFormat::SNIPPET),
-                additional_text_edits: None,
-            }),
+            Some(CompletionHint::InTableHeader | CompletionHint::Comma { .. }) | None => {
+                Some(Self {
+                    text_edit: CompletionTextEdit::Edit(TextEdit {
+                        new_text: format!("${{0:{key_name}}}"),
+                        range: key_range.into(),
+                    }),
+                    insert_text_format: Some(InsertTextFormat::SNIPPET),
+                    additional_text_edits: None,
+                })
+            }
         }
     }
 
@@ -263,7 +375,7 @@ impl CompletionEdit {
 
     pub fn new_schema_comment_directive(
         position: tombi_text::Position,
-        prefix_range: tombi_text::Range,
+        comment_range: tombi_text::Range,
         text_document_uri: &Url,
     ) -> Option<Self> {
         let file_name = std::path::Path::new(text_document_uri.path())
@@ -281,7 +393,7 @@ impl CompletionEdit {
             }),
             insert_text_format: Some(InsertTextFormat::SNIPPET),
             additional_text_edits: Some(vec![TextEdit {
-                range: prefix_range.into(),
+                range: comment_range.into(),
                 new_text: "".to_string(),
             }]),
         })
@@ -290,7 +402,7 @@ impl CompletionEdit {
     pub fn new_comment_directive(
         directive_name: &str,
         position: tombi_text::Position,
-        prefix_range: tombi_text::Range,
+        comment_range: tombi_text::Range,
     ) -> Option<Self> {
         Some(Self {
             text_edit: CompletionTextEdit::Edit(TextEdit {
@@ -299,7 +411,7 @@ impl CompletionEdit {
             }),
             insert_text_format: None,
             additional_text_edits: Some(vec![TextEdit {
-                range: prefix_range.into(),
+                range: comment_range.into(),
                 new_text: "".to_string(),
             }]),
         })
@@ -344,3 +456,33 @@ impl CompletionEdit {
         self
     }
 }
+
+fn head_comma_text_edits(
+    add_leading_comma: Option<AddLeadingComma>,
+    _add_trailing_comma: Option<AddTrailingComma>,
+    cursor_position: tombi_text::Position,
+) -> Option<Vec<TextEdit>> {
+    if let Some(AddLeadingComma { start_position }) = add_leading_comma {
+        let new_text = if start_position.line == cursor_position.line {
+            ", ".to_string()
+        } else {
+            format!(
+                ",{newlines}{spaces}",
+                newlines = "\n"
+                    .repeat((cursor_position.line.saturating_sub(start_position.line)) as usize),
+                spaces = " ".repeat(cursor_position.column as usize)
+            )
+        };
+
+        Some(vec![TextEdit {
+            range: tombi_text::Range {
+                start: start_position,
+                end: cursor_position,
+            }
+            .into(),
+            new_text,
+        }])
+    } else {
+        None
+    }
+}
