@@ -1,12 +1,13 @@
 use std::fmt::Write;
 
+use itertools::Itertools;
 use tombi_ast::AstNode;
 
 use crate::Format;
 
 impl Format for tombi_ast::KeyValue {
     fn format(&self, f: &mut crate::Formatter) -> Result<(), std::fmt::Error> {
-        self.leading_comments().collect::<Vec<_>>().format(f)?;
+        self.leading_comments().collect_vec().format(f)?;
 
         f.write_indent()?;
         self.keys().unwrap().format(f)?;
@@ -16,7 +17,7 @@ impl Format for tombi_ast::KeyValue {
         f.skip_indent();
         self.value().unwrap().format(f)?;
 
-        // NOTE: tailing comment is output by `value.fmt(f)`.
+        // NOTE: trailing comment is output by `value.fmt(f)`.
 
         Ok(())
     }
@@ -48,7 +49,7 @@ mod tests {
             r#"
             # leading comment1
             # leading comment2
-            key = "value"  # tailing comment
+            key = "value"  # trailing comment
             "#
         ) -> Ok(source);
     }
