@@ -316,6 +316,28 @@ mod table_keys_order {
                 "#
             )
         }
+
+        test_format! {
+            #[tokio::test]
+            async fn test_tool_maturin_include(
+                r#"
+                [tool.maturin]
+                include = [
+                  { path = "json.schemastore.org/**/*.json", format = "sdist" },
+                  { path = "json.tombi.dev/**/*.json", format = "sdist" },
+                ]
+                "#,
+                pyproject_schema_path(),
+            ) -> Ok(
+                r#"
+                [tool.maturin]
+                include = [
+                  { format = "sdist", path = "json.schemastore.org/**/*.json" },
+                  { format = "sdist", path = "json.tombi.dev/**/*.json" },
+                ]
+                "#
+            )
+        }
     }
 
     mod cargo {
@@ -620,6 +642,12 @@ mod table_keys_order {
             #[tokio::test]
             async fn test_header_order(
                 r#"
+                key2.key3 = "value1"
+                key1 = "value2"
+                key2.key4 = "value3"
+                key4 = "value4"
+                key5 = "value5"
+
                 [aaa]
                 key1 = "value1"
                 key2 = "value2"
@@ -632,6 +660,12 @@ mod table_keys_order {
                 key5 = "value5"
                 "#,
             ) -> Ok(r#"
+                key2.key3 = "value1"
+                key2.key4 = "value3"
+                key1 = "value2"
+                key4 = "value4"
+                key5 = "value5"
+
                 [aaa]
                 key1 = "value1"
                 key2 = "value2"
@@ -652,6 +686,12 @@ mod table_keys_order {
                 r#"
                 # tombi: format.rules.table-keys-order = "descending"
 
+                key2.key3 = "value1"
+                key1 = "value2"
+                key2.key4 = "value3"
+                key4 = "value4"
+                key5 = "value5"
+
                 [aaa]
                 key1 = "value1"
 
@@ -663,13 +703,25 @@ mod table_keys_order {
 
                 [ccc.ddd]
                 key4 = "value4"
+
+                [ccc.eee]
+                key5 = "value5"
                 "#,
             ) -> Ok(r#"
                 # tombi: format.rules.table-keys-order = "descending"
 
+                key5 = "value5"
+                key4 = "value4"
+                key2.key4 = "value3"
+                key2.key3 = "value1"
+                key1 = "value2"
+
                 [ccc]
                 key3 = "value3"
 
+                [ccc.eee]
+                key5 = "value5"
+
                 [ccc.ddd]
                 key4 = "value4"
 
