@@ -1,12 +1,12 @@
-use tombi_ast::{AstNode, AstToken};
+use tombi_ast::AstNode;
 
-use super::{AppendSemanticTokens, SemanticTokensBuilder, TokenType};
+use super::{AppendSemanticTokens, SemanticTokensBuilder};
 
 impl AppendSemanticTokens for tombi_ast::InlineTable {
     fn append_semantic_tokens(&self, builder: &mut SemanticTokensBuilder) {
         for comments in self.inner_begin_dangling_comments() {
             for comment in comments {
-                builder.add_token(TokenType::COMMENT, comment.as_ref().syntax().clone().into());
+                comment.append_semantic_tokens(builder);
             }
         }
 
@@ -14,18 +14,18 @@ impl AppendSemanticTokens for tombi_ast::InlineTable {
             key_value.append_semantic_tokens(builder);
             if let Some(comma) = comma {
                 for comment in comma.leading_comments() {
-                    builder.add_token(TokenType::COMMENT, comment.as_ref().syntax().clone().into());
+                    comment.append_semantic_tokens(builder);
                 }
 
-                if let Some(comment) = comma.tailing_comment() {
-                    builder.add_token(TokenType::COMMENT, comment.as_ref().syntax().clone().into())
+                if let Some(comment) = comma.trailing_comment() {
+                    comment.append_semantic_tokens(builder);
                 }
             }
         }
 
         for comments in self.inner_end_dangling_comments() {
             for comment in comments {
-                builder.add_token(TokenType::COMMENT, comment.as_ref().syntax().clone().into());
+                comment.append_semantic_tokens(builder);
             }
         }
     }
