@@ -1,5 +1,5 @@
 use regex::Regex;
-use tombi_comment_directive::value::{StringCommonLintRules, StringFormatRules};
+use tombi_comment_directive::value::{StringCommonFormatRules, StringCommonLintRules};
 use tombi_document_tree::ValueImpl;
 use tombi_future::{BoxFuture, Boxable};
 use tombi_schema_store::ValueSchema;
@@ -25,7 +25,7 @@ impl Validate for tombi_document_tree::String {
 
             let value_rules = if let Some(comment_directives) = self.comment_directives() {
                 let (value_rules, diagnostics) = get_tombi_key_table_value_rules_and_diagnostics::<
-                    StringFormatRules,
+                    StringCommonFormatRules,
                     StringCommonLintRules,
                 >(comment_directives, accessors)
                 .await;
